@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,14 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import WebSecurityScannerTransport
 from .grpc import WebSecurityScannerGrpcTransport
 from .grpc_asyncio import WebSecurityScannerGrpcAsyncIOTransport
-
+from .rest import WebSecurityScannerRestInterceptor, WebSecurityScannerRestTransport
 
 # Compile a registry of transports.
 _transport_registry = (
@@ -29,10 +27,12 @@ _transport_registry = (
 )  # type: Dict[str, Type[WebSecurityScannerTransport]]
 _transport_registry["grpc"] = WebSecurityScannerGrpcTransport
 _transport_registry["grpc_asyncio"] = WebSecurityScannerGrpcAsyncIOTransport
-
+_transport_registry["rest"] = WebSecurityScannerRestTransport
 
 __all__ = (
     "WebSecurityScannerTransport",
     "WebSecurityScannerGrpcTransport",
     "WebSecurityScannerGrpcAsyncIOTransport",
+    "WebSecurityScannerRestTransport",
+    "WebSecurityScannerRestInterceptor",
 )
