@@ -68,6 +68,7 @@ from google.cloud.websecurityscanner_v1beta.types import scan_config
 from .transports.base import DEFAULT_CLIENT_INFO, WebSecurityScannerTransport
 from .transports.grpc import WebSecurityScannerGrpcTransport
 from .transports.grpc_asyncio import WebSecurityScannerGrpcAsyncIOTransport
+from .transports.rest import WebSecurityScannerRestTransport
 
 
 class WebSecurityScannerClientMeta(type):
@@ -83,6 +84,7 @@ class WebSecurityScannerClientMeta(type):
     )  # type: Dict[str, Type[WebSecurityScannerTransport]]
     _transport_registry["grpc"] = WebSecurityScannerGrpcTransport
     _transport_registry["grpc_asyncio"] = WebSecurityScannerGrpcAsyncIOTransport
+    _transport_registry["rest"] = WebSecurityScannerRestTransport
 
     def get_transport_class(
         cls,
@@ -355,7 +357,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -1955,7 +1957,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "WebSecurityScannerClient":
         return self
 
     def __exit__(self, type, value, traceback):
